@@ -1,6 +1,5 @@
 package Net::Google::Spreadsheets::Worksheet;
 use Any::Moose;
-use namespace::autoclean;
 use Net::Google::DataAPI;
 
 with 'Net::Google::DataAPI::Role::Entry';
@@ -88,6 +87,9 @@ sub batchupdate_cell {
     } $res_feed->entries;
 }
 
+no Any::Moose;
+no Net::Google::DataAPI;
+
 1;
 __END__
 
